pub struct Error(/* private fields */);Expand description
Indicates that the operation failed due to an SQLite error.
Container operations are generally infallible. However, because our containers are backed by SQLite databases, they may still fail due to an internal SQLite error. Such errors can indicate a bug, but may also occur in out-of-memory situations.
Wraps the underlying RusqliteError.
Implementations
Sourceimpl Error
impl Error
pub fn into_inner(self) -> RusqliteError